@@ -2,13 +2,18 @@
 
 from __future__ import absolute_import, print_function, unicode_literals
 
+import inspect
 from functools import reduce
 from itertools import islice
-import inspect
 
 from rpy.functions import six
 
 
+def partial(f, *args, **opts):
+    def curried(*args1, **opts1):
+        return f(*args, *args1, **dict(opts, **opts1))
+    return curried
+
 def first(iterable, default=None):
     try:
         return next(iter(iterable))
